Struct rbx_binary::Deserializer [−][src]
pub struct Deserializer<'a> { /* fields omitted */ }Expand description
A configurable deserializer for Roblox binary models and places.
Example
use std::fs::File; use std::io::BufReader; use rbx_binary::Deserializer; let input = BufReader::new(File::open("File.rbxm")?); let deserializer = Deserializer::new(); let dom = deserializer.deserialize(input)?; // rbx_binary always returns a DOM with a DataModel at the top level. // To get to the instances from our file, we need to go one level deeper. println!("Root instances in file:"); for &referent in dom.root().children() { let instance = dom.get_by_ref(referent).unwrap(); println!("- {}", instance.name); }
Implementations